@@ -6,7 +6,7 @@
 
 
 
-check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x8, .x9, ..., .message, .choices = NULL, .data = list(), .value, .env, .call_up = 0, .arg_name){
+check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x8, .x9, ..., .message, .choices = NULL, .data = list(), .value, .env, .up, .arg_name){
   # This internal function tries to fully check the call to check_arg
   # in particular errors/warnings will pop when the types are ill-formed
 
@@ -18,19 +18,21 @@ check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x
 
   current_call = sys.call(sys.nframe() - 1)
 
-  FUN_NAME_FULL = deparse(current_call[[1]])
+  FUN_NAME_FULL = deparse_long(current_call[[1]])
 
   IS_VALUE = grepl("value", FUN_NAME_FULL)
   IS_PLUS = grepl("plus", FUN_NAME_FULL)
 
   FUN_NAME = ifelse(IS_VALUE, "check_value", "check_arg")
 
+  not_missing = function(arg) deparse(substitute(arg)) %in% names(current_call)
+
   #
   # Basic Arguments ####
   #
 
   # .message: character scalar
-  if(!missing(.message)){
+  if(not_missing(.message)){
     if(length(.message) != 1){
       stop_up(up = 1, "Argument '.message' must be a character string of length 1. Currently it is of length ", length(.message), ".")
     }
@@ -40,39 +42,40 @@ check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x
   }
 
   # .choices: character vector
-  if(!missing(.choices) && !is.null(.choices)){
+  if(not_missing(.choices) && !is.null(.choices)){
     if(!is.character(.choices)){
       stop_up(up = 1, "Argument '.choices' must be a character vector. Currently it is not of type character.")
     }
   }
 
   # .env: an environment
-  if(!missing(.env)){
+  if(not_missing(.env)){
     if(!is.environment(.env)){
       stop_up(up = 1, "Argument '.env' must be an environment (default it is the environment from the main call of the function). Currently it is not an environment.")
     }
   }
 
-  # .call_up: integer scalar
-  if(!missing(.call_up)){
-    if(length(.call_up) != 1){
-      stop_up(up = 1, "Argument '.call_up' must be a positive integer scalar. Currently it is of length ", length(.call_up), ".")
+  # .up: integer scalar
+
+  if(not_missing(.up)){
+    if(length(.up) != 1){
+      stop_up(up = 1, "Argument '.up' must be a positive integer scalar. Currently it is of length ", length(.up), ".")
     }
-    if(!is.numeric(.call_up)){
-      stop_up(up = 1, "Argument '.call_up' must be a positive integer scalar. Currently it is not numeric.")
+    if(!is.numeric(.up)){
+      stop_up(up = 1, "Argument '.up' must be a positive integer scalar. Currently it is not numeric.")
     }
-    if((.call_up - floor(.call_up)) != 0){
-      stop_up(up = 1, "Argument '.call_up' must be a positive integer scalar. Currently it is not an integer although numeric.")
+    if((.up - floor(.up)) != 0){
+      stop_up(up = 1, "Argument '.up' must be a positive integer scalar. Currently it is not an integer although numeric.")
     }
-    if(.call_up < 0){
-      stop_up(up = 1, "Argument '.call_up' must be a positive integer scalar. Currently it is not positive.")
+    if(.up < 0){
+      stop_up(up = 1, "Argument '.up' must be a positive integer scalar. Currently it is not positive.")
     }
   }
 
   # .value: integer scalar
-  if(!missing(.value)){
+  if(not_missing(.value)){
     if(length(.value) != 1){
-      stop_up(up = 1, "Argument '.value' must be a positive integer scalar. Currently it is of length ", length(.call_up), ".")
+      stop_up(up = 1, "Argument '.value' must be a positive integer scalar. Currently it is of length ", length(.value), ".")
     }
     if(!is.numeric(.value)){
       stop_up(up = 1, "Argument '.value' must be a positive integer scalar. Currently it is not numeric.")
@@ -86,7 +89,7 @@ check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x
   }
 
   # .arg_name: character scalar
-  if(!missing(.arg_name)){
+  if(not_missing(.arg_name)){
     if(length(.arg_name) != 1){
       stop_up(up = 1, "Argument '.arg_name' must be a character string of length 1. Currently it is of length ", length(.arg_name), ".")
     }
@@ -95,7 +98,8 @@ check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x
     }
   }
 
-
+  sysUp = sys.parent()
+  mc = match.call(definition = sys.function(sysUp), call = sys.call(sysUp), expand.dots = FALSE)
 
   if(IS_VALUE == FALSE){
     #
@@ -103,13 +107,20 @@ check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x
     #
 
     IS_DOTS = identical(current_call[[2]], quote(...))
-    sysUp = sys.parent()
-    mc = match.call(definition = sys.function(sysUp), call = sys.call(sysUp), expand.dots = FALSE)
     mc_arg = mc[match(names(mc), c(".x", ".type", ".x1", ".x2", ".x3", ".x4", ".x5", ".x6", ".x7", ".x8", ".x9"), nomatch = 0) > 0]
 
-    sysOrigin = sys.parent(.call_up + 2) # I checked, this is 1
+    sysOrigin = sys.parent(.up + 2)
     mc_origin = match.call(definition = sys.function(sysOrigin), call = sys.call(sysOrigin), expand.dots = FALSE)
 
+    #
+    # Error if dots arguments provided
+    #
+
+    if("..." %in% names(mc) && !is.null(names(mc[["..."]]))){
+      arg_pblm = names(mc[["..."]])
+      stop_up("Argument", enumerate_items(arg_pblm, "s.is"), " not valid. If it was an argument to be checked, please use only .x, .x1 to .x9 and .type.")
+    }
+
     #
     # Finding the type
     #
@@ -119,7 +130,7 @@ check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x
       nb_args = length(current_call) - 2
     } else {
       # We count the number of unnamed args or with names in .x[d] .type
-      nb_args = length(current_call[!names(current_call) %in% c(".message", ".choices", ".data", ".env", ".call_up")]) - 2
+      nb_args = length(current_call[!names(current_call) %in% c(".message", ".choices", ".data", ".env", ".up")]) - 2
     }
 
     if(nb_args < 1){
@@ -161,7 +172,7 @@ check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x
     } else {
       type = NULL
       if(!is.null(names(current_call))){
-        current_call = current_call[!names(current_call) %in% c(".message", ".choices", ".data", ".env", ".call_up")]
+        current_call = current_call[!names(current_call) %in% c(".message", ".choices", ".data", ".env", ".up")]
       }
 
       if(IS_DOTS){
@@ -195,25 +206,65 @@ check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x
         is_name = sapply(mc_arg, is.name)
         if(any(!is_name)){
           # we check if it's because it's alist
-          is_list = sapply(mc_arg, function(x) is.call(x) && grepl("^[\\.[:alpha:]][[:alnum:]\\._]*\\$", deparse(x)))
+          is_list = sapply(mc_arg, function(x) is.call(x) && grepl("^[\\.[:alpha:]][[:alnum:]\\._]*\\$", deparse_long(x)))
           if(all(!is_name & is_list)){
             stop_up(up = 1, "You cannot check list elements in check_arg, but you can in check_arg_plus. Please refer to Section XIII) in the examples.")
           } else {
-            stop_up(up = 1, "In check_arg, the arguments '.x' to '.x9' must be argument names. This is not the case for '", deparse(mc_arg[[which(!is_name)[1]]]), "'. Please refer to the details/examples/vignette.")
+            stop_up(up = 1, "In check_arg, the arguments '.x' to '.x9' must be argument names. This is not the case for '", deparse_long(mc_arg[[which(!is_name)[1]]]), "'. Please refer to the details/examples/vignette.")
           }
 
         }
       } else {
         # => all names and lists base$var
         is_name = sapply(mc_arg, is.name)
-        is_list = sapply(mc_arg, function(x) is.call(x) && grepl("^[\\.[:alpha:]][[:alnum:]\\._]*\\$", deparse(x)))
+        is_list = sapply(mc_arg, function(x) is.call(x) && grepl("^[\\.[:alpha:]][[:alnum:]\\._]*\\$", deparse_long(x)))
         is_ok = is_name | is_list
         if(any(!is_ok)){
-          stop_up(up = 1, "In check_arg_plus, the arguments '.x' to '.x9' must be argument names (or list elements). This is not the case for '", deparse(mc_arg[[which(!is_ok)[1]]]), "'. Please refer to the details/examples/vignette.")
+          stop_up(up = 1, "In check_arg_plus, the arguments '.x' to '.x9' must be argument names (or list elements). This is not the case for '", deparse_long(mc_arg[[which(!is_ok)[1]]]), "'. Please refer to the details/examples/vignette.")
         }
       }
     }
 
+    # Now we check for a super nasty error: when the arg names of an internal function don't match the arg names
+    # of the original function
+    # Default behavior is that the argument is left unchecked => not GOOD! this can lead to BIG PROBLEMS
+    # And for check_arg users, it's impossible to find out their mistake.
+    #
+
+    if(!IS_DOTS){
+      x_names = sapply(mc_arg, deparse_long)
+
+      args_origin = names(formals(sys.function(sysOrigin)))
+      if(is.null(args_origin)){
+        stop_up("The function '", deparse_long(mc_origin[[1]]), "' has no argument. Thus check_arg cannot check the argument", enumerate_items(x_names, "s.quote"), " given in input.")
+      }
+
+      arg_pblm = setdiff(x_names, args_origin)
+      if(length(arg_pblm) > 0){
+
+        is_list = FALSE
+        if(any(grepl("$", arg_pblm, fixed = TRUE))){
+          new_args = gsub("\\$.+", "", arg_pblm)
+          arg_pblm = setdiff(new_args, args_origin)
+          is_list = length(arg_pblm) == 0
+        } else if(any(grepl("\\[\\[", arg_pblm, fixed = TRUE))){
+          stop_up("To check elements of arguments that are lists, you must use the dollar sign: arg$element.")
+        }
+
+        if(is_list){
+          if(!IS_PLUS){
+            stop_up("To check elements of arguments that are lists, you must use check_arg_plus (and not check_arg).")
+          }
+        } else {
+          msg = ifelse(.up > 0, "The arguments passed to your internal function must have the exact same name as in the user-level function.\n If you really want to change the name of the argument in your internal function, a workaround is to use 'check_value' in combination with the argument '.arg_name' which gives the original name the argument refers to.", "")
+          stop_up("The argument", enumerate_items(arg_pblm, "s.quote.isn't"), " valid: ", ifsingle(arg_pblm, "it is not an argument", "they are not arguments"), " of function '", deparse_long(mc_origin[[1]]), "'. It's a big problem! ", msg)
+        }
+
+      }
+
+    }
+
+
   } else {
     #
     # CHECK VALUE ####
@@ -232,7 +283,7 @@ check_dreamerr_calls = function(.x, .type, .x1, .x2, .x3, .x4, .x5, .x6, .x7, .x
 
     type = .type
 
-    if(missing(.x)){
+    if(!".x" %in% names(mc)){
       stop_up(up = 1, "The argument '.x' is required. Problem: it is currently missing.")
     }
 
